
------------------------------------------
-- Metadata

PLAYERZONE_VERSION = GetAddOnMetadata("PlayerZone", "Version");
PLAYERZONE_AUTHOR = GetAddOnMetadata("PlayerZone", "Author");
PLAYERZONE_XDATE = GetAddOnMetadata("PlayerZone", "X-Date");
PLAYERZONE_XWEBSITE = GetAddOnMetadata("PlayerZone", "X-Website");
----------------------------------------
-- Default Options

PlayerZone_Options = {
	show = true,
	lock = false,
	tooltip = true,
	worldmap = true,
	plugin = true,
	red = 1,
	green = 1,
	blue = 1,
	disable = false,
	showLM = true,
	position = 1,
};

-------------------------------------------
-- OnLoad

function PlayerZone_OnLoad(self)
	SLASH_PLAYERZONE1 = "/playerzone";
	SLASH_PLAYERZONE2 = "/pz";
	SlashCmdList[ "PLAYERZONE"] = PlayerZone_SlashCommand;
	self:RegisterEvent("VARIABLES_LOADED");
	self:RegisterEvent("ZONE_CHANGED_NEW_ARENA");
end

-----------------------------------------------
-- Slash Commands

function PlayerZone_SlashCommand(msg)
	msg = string.lower(msg);
	local args = {};
	for word in string.gmatch(msg, "[^%s]+") do
		table.insert(args, word);
	end
	if ( args[1] ) then
		if (args[1] == "commands" ) then
			PlayerZone_SlashCommands_Toggle();
		elseif ( args[1] == "options" ) then
			PlayerZone_Options_Toggle();
		elseif ( args[1] == "show" ) then
			if ( args[2] == "playerzone" ) then
				PlayerZone_Options.show = not PlayerZone_Options.show;
			elseif ( args[2] == "levelmap" ) then
				PlayerZone_Options.showLM = not PlayerZone_Options.showLM
				PlayerZone_MapLevel_Toggle()
			end
			PlayerZone_Toggle();
		elseif ( args[1] == "lock" ) then
				PlayerZone_Options.lock = not PlayerZone_Options.lock;
		elseif ( args[1] == "tooltip" ) then
			PlayerZone_Options.tooltip = not PlayerZone_Options.tooltip;
		elseif ( args[1] == "worldmap" ) then
			PlayerZone_WorldMap_Toggle();
		elseif ( args[1] == "plugin" ) then
			PlayerZone_Plugin_Toggle();
		elseif ( args[1] == "alpha" ) then
			local alpha = tonumber(args[2])
			if ( alpha and alpha >= 0 and alpha <= 1 ) then
				PlayerZone_Options.alpha = alpha;
				PlayerZone_Frame:SetBackdropColor(PlayerZone_Options.red, PlayerZone_Options.green, PlayerZone_Options.blue, PlayerZone_Options.alpha)
				LevelZone_Frame:SetBackdropColor(PlayerZone_Options.red, PlayerZone_Options.green, PlayerZone_Options.blue, PlayerZone_Options.alpha)
			else
				PlayerZone_Message(PLAYERZONE_OPTIONS_ALPHAWRONG);
			end
		elseif ( args[1] == "framecolor" ) then
			local red = tonumber(args[2]);
			local green = tonumber(args[3]);
			local blue = tonumber(args[4]);
			if ( red and red >= 0 and red <= 1 ) then
				PlayerZone_Options.red = red;
				if ( green and green >=0 and green <=1 ) then
					PlayerZone_Options.green = green;
					if ( blue and blue >=0 and blue <=1 ) then
						PlayerZone_Options.blue = blue;
						PlayerZone_Frame:SetBackdropColor(PlayerZone_Options.red, PlayerZone_Options.green, PlayerZone_Options.blue, PlayerZone_Options.alpha)
						LevelZone_Frame:SetBackdropColor(PlayerZone_Options.red, PlayerZone_Options.green, PlayerZone_Options.blue, PlayerZone_Options.alpha)
					else
						PlayerZone_Message(PLAYERZONE_OPTIONS_COLORWRONG);
					end
				else
					PlayerZone_Message(PLAYERZONE_OPTIONS_COLORWRONG);
				end
			else
				PlayerZone_Message(PLAYERZONE_OPTIONS_COLORWRONG);
			end
		elseif (args[1] == "abouts" ) then
				PlayerZone_Version_Toggle();
		elseif (args[1] == "disable") then
				PlayerZone_Disable();
		else
			PlayerZone_Message(PLAYERZONE_NOCOMMAND);
		end
	else 
		PlayerZone_Message(PLAYERZONE_USAGE);
		PlayerZone_Message("options - "..PLAYERZONE_OPTIONS);
		PlayerZone_Message("commands - "..PLAYERZONE_OPTIONS_COMMANDS2);
		if ( PlayerZone_Options.show ) then
			PlayerZone_Message("show playerzone - "..PLAYERZONE_ACTIF..PLAYERZONE_OPTIONS_SHOW);
		else
			PlayerZone_Message("show playerzone - "..PLAYERZONE_INACTIF..PLAYERZONE_OPTIONS_SHOW);
		end
		if ( PlayerZone_Options.lock ) then
			PlayerZone_Message("lock - "..PLAYERZONE_ACTIF..PLAYERZONE_OPTIONS_LOCK);
		else
			PlayerZone_Message("lock - "..PLAYERZONE_INACTIF..PLAYERZONE_OPTIONS_LOCK);
		end
		if ( PlayerZone_Options.tooltip ) then
			PlayerZone_Message("tooltip - "..PLAYERZONE_ACTIF..PLAYERZONE_OPTIONS_TOOLTIP);
		else
			PlayerZone_Message("tooltip - "..PLAYERZONE_INACTIF..PLAYERZONE_OPTIONS_TOOLTIP);
		end
		if ( PlayerZone_Options.worldmap ) then
			PlayerZone_Message("worldmap - "..PLAYERZONE_ACTIF..PLAYERZONE_OPTIONS_WORLDMAP);
		else
			PlayerZone_Message("worldmap - "..PLAYERZONE_INACTIF..PLAYERZONE_OPTIONS_WORLDMAP);
		end
		if ( PlayerZone_Options.plugin ) then
			PlayerZone_Message("plugin - "..PLAYERZONE_ACTIF..PLAYERZONE_OPTIONS_PLUGIN);
		else
			PlayerZone_Message("plugin - "..PLAYERZONE_INACTIF..PLAYERZONE_OPTIONS_PLUGIN);
		end
		PlayerZone_Message("disable - "..PLAYERZONE_USAGE_DISABLE);
		PlayerZone_Message("alpha <0 ~ 1> - "..PLAYERZONE_OPTIONS_ALPHA);
		PlayerZone_Message("framecolor <0~1> <0~1> <0~1> - "..PLAYERZONE_OPTIONS_COLOR_FRAME);
		PlayerZone_Message("abouts - "..PLAYERZONE_OPTIONS_VERSION);
		if ( PZ_Options_Frame:IsShown() ) then
			PlayerZone_Options_Init();
		end
	end
end

----------------------------------------
-- Toggle Options Frame

function PlayerZone_Toggle()
	if ( PlayerZone_Frame:IsShown() ) then
		PlayerZone_Frame:Hide();
		PlayerZone_Options.show = false;
	else
		PlayerZone_Frame:Show();
		PlayerZone_Options.show = true;
	end
end

----------------------------------------
-- Toggle SlashCommands Frame

function PlayerZone_SlashCommands_Toggle()
	if ( PlayerZone_SlashCommands_Frame:IsShown() ) then
		PlayerZone_SlashCommands_Frame:Hide();
	else
		PlayerZone_SlashCommands_Frame:Show();
	end
end

---------------------------------------
-- Toggle Version Frame
function PlayerZone_Version_Toggle()
	if ( PlayerZone_Version_Frame:IsShown() ) then
		PlayerZone_Version_Frame:Hide();
	else
		PlayerZone_Version_Frame:Show();
	end
end

-----------------------------------------
-- OnUpdate

function PlayerZone_OnUpdate(self, elapsed)
	local zoneName = GetZoneText();
	local subZoneName = GetSubZoneText();
	local pvpType, isFFA, faction = GetZonePVPInfo();
	local realZoneName = GetRealZoneText();
	
		PlayerZone_Frame_Text1:SetText(zoneName);
		pZFSize = 0;
		if ( #zoneName > #subZoneName ) then
			if ( #zoneName > 12 ) then
				pZFSize = #zoneName * 7;
			else
				pZFSize = #zoneName * 10;
			end
		else
			if ( #subZoneName > 12 ) then
				pZFSize = #subZoneName * 7;
			else
				pZFSize = #subZoneName * 10;
			end
		end	
		if ( #subZoneName == 0 ) then
			PlayerZone_Frame:SetHeight(25);
		else
			PlayerZone_Frame:SetHeight(36);
		end
		PlayerZone_Frame:SetWidth(pZFSize);
		PlayerZone_Frame_Text2:SetText(subZoneName);
if ( pvpType == "friendly" ) then
		PlayerZone_Frame_Text1:SetTextColor(0, 1, 0);
		PlayerZone_Frame_Text2:SetTextColor(0, 1, 0);
elseif ( pvpType == "hostile" ) then
		PlayerZone_Frame_Text1:SetTextColor(1, 0, 0);
		PlayerZone_Frame_Text2:SetTextColor(1, 0, 0);
else
		PlayerZone_Frame_Text1:SetTextColor(1, 1, 0);
		PlayerZone_Frame_Text2:SetTextColor(1, 1, 0);

end

end

----------------------------------------------------
-- Chat Message

function PlayerZone_Message(msg)
	DEFAULT_CHAT_FRAME:AddMessage("[PlayerZone] "..msg);
end

-------------------------------------------------
-- GameTooltips

function PlayerZone_OnEnter(self)
	if ( PlayerZone_Options.tooltip ) then
		GameTooltip_SetDefaultAnchor(GameTooltip, self);
		GameTooltip:SetText(PLAYERZONE_TOOLTIP_TITLE);
		GameTooltip:AddLine(PLAYERZONE_TOOLTIP_SUBTITLE);
		if ( PlayerZone_Options.lock ) then
			GameTooltip:AddLine(PLAYERZONE_TOOLTIP_LOCKED);
		else
			GameTooltip:AddLine(PLAYERZONE_TOOLTIP_LEFTCLICK);
		end
		GameTooltip:AddLine(PLAYERZONE_TOOLTIP_RIGHTCLICK);
		GameTooltipTextLeft1:SetTextColor(1, 1, 1);
		GameTooltipTextLeft2:SetTextColor(1, 0.8, 0);
		GameTooltip:Show();
	end
end

--------------------------------------------------
-- Toggle WorldMap Frame

function PlayerZone_WorldMap_Toggle()
	if ( PZ_WorldMap_Frame:IsShown() ) then
		PZ_WorldMap_Frame:Hide();
		PlayerZone_Options.worldmap = false;
	else
		PZ_WorldMap_Frame:Show();
		PlayerZone_Options.worldmap = true;
	end
end

--------------------------------------------------
-- OnEvent

function PlayerZone_OnEvent(self, event, ...)
	if ( event == "VARIABLES_LOADED" ) then
		PlayerZone_InitDisplay()
		PlayerZone_Options_Init()		
	elseif ( event == "ZONE_CHANGED_NEW_ARENA" ) then
		SetMapToCurrentZone()
	end
end

------------------------------------------------
-- Display Initialization

function PlayerZone_InitDisplay()
	if ( not PlayerZone_Options.show ) then
		PlayerZone_Frame:Hide()
	end
	if ( not PlayerZone_Options.showLM ) then
		InfoZoneFrame:Hide()
	end
	if ( not PlayerZone_Options.worldmap ) then
		PZ_WorldMap_Frame:Hide()
	end
	if ( not PlayerZone_Options.plugin ) then
		PlayerZoneButtonFrame:Hide()
	end
	PlayerZone_Frame:SetBackdropColor(PlayerZone_Options.red, PlayerZone_Options.green, PlayerZone_Options.blue, PlayerZone_Options.alpha)
	LevelZone_Frame:SetBackdropColor(PlayerZone_Options.red, PlayerZone_Options.green, PlayerZone_Options.blue, PlayerZone_Options.alpha)
end

--------------------------------------------------
-- Toggle Options Frame
function PlayerZone_Options_Toggle()
	if ( PZ_Options_Frame:IsShown() ) then
		PZ_Options_Frame:Hide();
		PlaySound("GAMEDIALOGCLOSE")
	else
		PZ_Options_Frame:Show();
		PlaySound("GAMEDIALOGOPEN")
	end
end

-------------------------------------------------
-- Toggle PlayerZone Abouts Frame
function PlayerZone_Abouts_Toggle()
	if ( PlayerZone_Version_Frame:IsShown() ) then
		PlayerZone_Version_Frame:Hide();
	else
		PlayerZone_Version_Frame:Show();
	end
end 

------------------------------------------------
-- Toggle PlayerZone Commands Frame
function PlayerZone_Commands_Toggle()
	if ( PlayerZone_SlashCommands_Frame:IsShown() ) then
		PlayerZone_SlashCommands_Frame:Hide();
	else
		PlayerZone_SlashCommands_Frame:Show();
	end
end 

-----------------------------------------------
-- Abouts Tooltip

function PlayerZoneAbouts_OnEnter(self)
	if ( PlayerZone_Options.tooltip ) then
		GameTooltip_SetDefaultAnchor(GameTooltip, self);
		GameTooltip:AddLine(PLAYERZONE_OPTIONS_VERSION);
		GameTooltip:Show();
	end
end

------------------------------------------------
-- Toggle Map Level adn Instances

function PlayerZone_MapLevel_Toggle()
	if ( PlayerZone_Options.showLM ) then
		InfoZoneFrame:Show()
	else
		InfoZoneFrame:Hide()
	end
end